@@ -6,6 +6,12 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
+// Flag names.
+const (
+	flgKeep   = "keep"
+	flgReason = "reason"
+)
+
 func createRevoke() *cli.Command {
 	return &cli.Command{
 		Name:   "revoke",
@@ -13,12 +19,12 @@ func createRevoke() *cli.Command {
 		Action: revoke,
 		Flags: []cli.Flag{
 			&cli.BoolFlag{
-				Name:    "keep",
+				Name:    flgKeep,
 				Aliases: []string{"k"},
 				Usage:   "Keep the certificates after the revocation instead of archiving them.",
 			},
 			&cli.UintFlag{
-				Name: "reason",
+				Name: flgReason,
 				Usage: "Identifies the reason for the certificate revocation." +
 					" See https://www.rfc-editor.org/rfc/rfc5280.html#section-5.3.1." +
 					" Valid values are:" +
@@ -41,15 +47,15 @@ func revoke(ctx *cli.Context) error {
 	certsStorage := NewCertificatesStorage(ctx)
 	certsStorage.CreateRootFolder()
 
-	for _, domain := range ctx.StringSlice("domains") {
+	for _, domain := range ctx.StringSlice(flgDomains) {
 		log.Printf("Trying to revoke certificate for domain %s", domain)
 
-		certBytes, err := certsStorage.ReadFile(domain, ".crt")
+		certBytes, err := certsStorage.ReadFile(domain, certExt)
 		if err != nil {
 			log.Fatalf("Error while revoking the certificate for domain %s\n\t%v", domain, err)
 		}
 
-		reason := ctx.Uint("reason")
+		reason := ctx.Uint(flgReason)
 
 		err = client.Certificate.RevokeWithReason(certBytes, &reason)
 		if err != nil {
@@ -58,7 +64,7 @@ func revoke(ctx *cli.Context) error {
 
 		log.Println("Certificate was revoked.")
 
-		if ctx.Bool("keep") {
+		if ctx.Bool(flgKeep) {
 			return nil
 		}
 
