@@ -11,6 +11,7 @@ import (
 	"github.com/dnsimple/dnsimple-go/dnsimple"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/useragent"
 	"golang.org/x/oauth2"
 )
 
@@ -77,7 +78,7 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 
 	ts := oauth2.StaticTokenSource(&oauth2.Token{AccessToken: config.AccessToken})
 	client := dnsimple.NewClient(oauth2.NewClient(context.Background(), ts))
-	client.SetUserAgent("go-acme/lego")
+	client.SetUserAgent(useragent.Get())
 
 	if config.BaseURL != "" {
 		client.BaseURL = config.BaseURL
