@@ -10,6 +10,7 @@ import (
 
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/useragent"
 	"github.com/ovh/go-ovh/ovh"
 )
 
@@ -271,7 +272,7 @@ func newClient(config *Config) (*ovh.Client, error) {
 		return nil, fmt.Errorf("new client: %w", err)
 	}
 
-	client.UserAgent = "go-acme/lego"
+	client.UserAgent = useragent.Get()
 
 	return client, nil
 }
