@@ -11,8 +11,10 @@ import (
 
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/useragent"
 	selectelapi "github.com/selectel/domains-go/pkg/v2"
 	"github.com/selectel/go-selvpcclient/v3/selvpcclient"
+	"golang.org/x/net/idna"
 )
 
 const tokenHeader = "X-Auth-Token"
@@ -25,8 +27,6 @@ const (
 	defaultHTTPTimeout        = 30 * time.Second
 )
 
-const defaultUserAgent = "go-acme/lego"
-
 const (
 	envNamespace = "SELECTELV2_"
 
@@ -114,7 +114,7 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 	}
 
 	headers := http.Header{}
-	headers.Set("User-Agent", defaultUserAgent)
+	useragent.SetHeader(headers)
 
 	return &DNSProvider{
 		baseClient: selectelapi.NewClient(config.BaseURL, config.HTTPClient, headers),
@@ -253,7 +253,12 @@ type clientWrapper struct {
 }
 
 func (w *clientWrapper) getZone(ctx context.Context, name string) (*selectelapi.Zone, error) {
-	params := &map[string]string{"filter": name}
+	unicodeName, err := idna.ToUnicode(name)
+	if err != nil {
+		return nil, fmt.Errorf("to unicode: %w", err)
+	}
+
+	params := &map[string]string{"filter": unicodeName}
 
 	zones, err := w.ListZones(ctx, params)
 	if err != nil {
@@ -261,13 +266,13 @@ func (w *clientWrapper) getZone(ctx context.Context, name string) (*selectelapi.
 	}
 
 	for _, zone := range zones.GetItems() {
-		if zone.Name == dns01.ToFqdn(name) {
+		if zone.Name == dns01.ToFqdn(unicodeName) {
 			return zone, nil
 		}
 	}
 
 	if len(strings.Split(dns01.UnFqdn(name), ".")) == 1 {
-		return nil, errors.New("zone for challenge has not been found")
+		return nil, fmt.Errorf("zone '%s' for challenge has not been found", name)
 	}
 
 	// -1 can not be returned since if no dots present we exit above
@@ -277,7 +282,12 @@ func (w *clientWrapper) getZone(ctx context.Context, name string) (*selectelapi.
 }
 
 func (w *clientWrapper) getRRset(ctx context.Context, name, zoneID string) (*selectelapi.RRSet, error) {
-	params := &map[string]string{"name": name, "rrset_types": string(selectelapi.TXT)}
+	unicodeName, err := idna.ToUnicode(name)
+	if err != nil {
+		return nil, fmt.Errorf("to unicode: %w", err)
+	}
+
+	params := &map[string]string{"name": unicodeName, "rrset_types": string(selectelapi.TXT)}
 
 	resp, err := w.ListRRSets(ctx, zoneID, params)
 	if err != nil {
@@ -285,7 +295,7 @@ func (w *clientWrapper) getRRset(ctx context.Context, name, zoneID string) (*sel
 	}
 
 	for _, rrset := range resp.GetItems() {
-		if rrset.Name == dns01.ToFqdn(name) {
+		if rrset.Name == dns01.ToFqdn(unicodeName) {
 			return rrset, nil
 		}
 	}
