@@ -8,6 +8,7 @@ import (
 
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/useragent"
 	"github.com/ultradns/ultradns-go-sdk/pkg/client"
 	"github.com/ultradns/ultradns-go-sdk/pkg/record"
 	"github.com/ultradns/ultradns-go-sdk/pkg/rrset"
@@ -24,12 +25,10 @@ const (
 	EnvTTL                = envNamespace + "TTL"
 	EnvPropagationTimeout = envNamespace + "PROPAGATION_TIMEOUT"
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
-
-	// Default variables names.
-	defaultEndpoint  = "https://api.ultradns.com/"
-	defaultUserAgent = "go-acme/lego"
 )
 
+const defaultEndpoint = "https://api.ultradns.com/"
+
 // DNSProvider implements the challenge.Provider interface.
 type DNSProvider struct {
 	config *Config
@@ -83,7 +82,7 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		Username:  config.Username,
 		Password:  config.Password,
 		HostURL:   config.Endpoint,
-		UserAgent: defaultUserAgent,
+		UserAgent: useragent.Get(),
 	}
 
 	uClient, err := client.NewClient(ultraConfig)
